AsTrace

Trait AsTrace 

pub trait AsTrace: Sealed {
    type Trace;

    // Required method
    fn as_trace(&self) -> Self::Trace;
}
Trait implemented for log types that can be converted to a tracing equivalent.

Required Associated Types

type Trace

The tracing type that this type can be converted into.

Required Methods

fn as_trace(&self) -> Self::Trace

Returns the tracing equivalent of self.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl AsTrace for Level

Source

impl AsTrace for LevelFilter

Source

impl<'a> AsTrace for Metadata<'a>

Source

type Trace = Metadata<'a>

Source

fn as_trace(&self) -> Self::Trace

Source

impl<'a> AsTrace for Record<'a>

Source

type Trace = Metadata<'a>

Source

fn as_trace(&self) -> Self::Trace

Implementors